pub struct BringIntoViewResponder { /* private fields */ }Expand description
A scroll container’s ability to scroll a target window rect into view.
Installed into composition by scroll containers via
local_bring_into_view_responder and read by a focused text field. Equality
is by identity so providing the same remembered responder does not thrash the
composition local.
Implementations
Sourceimpl BringIntoViewResponder
impl BringIntoViewResponder
Sourcepub fn new(responder: impl Fn(Rect, f32) + 'static) -> Self
pub fn new(responder: impl Fn(Rect, f32) + 'static) -> Self
Builds a responder from a callback that receives the caret’s window rect and the keyboard inset (px covering the viewport bottom).
Sourcepub fn bring_into_view(&self, caret_window_rect: Rect, ime_bottom: f32)
pub fn bring_into_view(&self, caret_window_rect: Rect, ime_bottom: f32)
Asks the container to scroll caret_window_rect clear of a keyboard that
covers the bottom ime_bottom px of the viewport.