pub fn rememberScrollableState(
on_delta: impl Fn(f32) -> f32 + 'static,
) -> ScrollableStateExpand description
Remembers scroll input state and updates its consumption handler.
pub fn rememberScrollableState(
on_delta: impl Fn(f32) -> f32 + 'static,
) -> ScrollableStateRemembers scroll input state and updates its consumption handler.