pub enum ImagePixelFormat {
Rgba8,
Alpha8 {
color: [u8; 3],
},
}Expand description
Storage format of an immutable bitmap.
Variants
Rgba8
Four bytes per pixel, ordered red, green, blue, alpha.
Alpha8
One alpha byte per pixel and a constant, unpremultiplied RGB color.