pub fn command_draw_scope(size: Size) -> DrawScopeDefaultExpand description
The scope every framework-run draw command records into: sized by the consumer, measuring text with the app’s fonts.
pub fn command_draw_scope(size: Size) -> DrawScopeDefaultThe scope every framework-run draw command records into: sized by the consumer, measuring text with the app’s fonts.