pub fn log_layout_tree(layout: &LayoutTree)Expand description
Logs the current layout tree through the logger with indentation showing hierarchy.
pub fn log_layout_tree(layout: &LayoutTree)Logs the current layout tree through the logger with indentation showing hierarchy.