pub enum LocalizationError {
Preference(String),
InvalidLocale(String),
InvalidResource {
resource: String,
detail: String,
},
Format {
namespace: String,
id: String,
detail: String,
},
}Expand description
A catalog, locale, or message could not be used.
Variants
Preference(String)
A language preference could not be read or saved.
InvalidLocale(String)
The requested language tag is invalid.
InvalidResource
A Fluent resource is malformed or contains duplicate definitions.
Fields
Format
Neither a translation nor the source could be formatted.