pub type LocalizedText = SharedText;Expand description
A formatted translation with shared text storage and owned-string conversions.
Aliased Type
pub struct LocalizedText(/* private fields */);pub type LocalizedText = SharedText;A formatted translation with shared text storage and owned-string conversions.
pub struct LocalizedText(/* private fields */);