message!() { /* proc-macro */ }Expand description
Captures readable source text and arguments for translation when displayed.
Accepts the same syntax as tr!, but works outside composition.
message!() { /* proc-macro */ }Captures readable source text and arguments for translation when displayed.
Accepts the same syntax as tr!, but works outside composition.