pub enum PatchFill {
Stretch,
Tile,
}Expand description
How a region larger than its source is filled.
Variants
Stretch
Scale the source to fill the region.
Tile
Repeat the source at its own size, clipping the last row and column.
Implementations