pub struct WindowInsets {
pub safe_area: EdgeInsets,
pub ime: EdgeInsets,
}Expand description
Insets needed to keep content clear of system UI and the on-screen keyboard.
Fields
safe_area: EdgeInsetsime: EdgeInsetsImplementations
Sourceimpl WindowInsets
impl WindowInsets
Sourcepub fn combined(self) -> EdgeInsets
pub fn combined(self) -> EdgeInsets
Combines overlapping insets by taking the largest obstruction on each edge.