pub struct TextLayoutResult {
pub width: f32,
pub height: f32,
pub line_height: f32,
pub lines: Vec<LineLayout>,
/* private fields */
}Fields
width: f32Total width of laid out text
height: f32Total height of laid out text
line_height: f32Height of a single line
lines: Vec<LineLayout>Line layout information
Implementations
Sourceimpl TextLayoutResult
impl TextLayoutResult
Sourcepub fn new(text: &str, data: TextLayoutData) -> Self
pub fn new(text: &str, data: TextLayoutData) -> Self
Creates a new layout result with the given glyph positions.
Sourcepub fn get_cursor_x(&self, byte_offset: usize) -> f32
pub fn get_cursor_x(&self, byte_offset: usize) -> f32
Returns X position for cursor at given byte offset. Uses logical byte boundaries, including positions shared by a shaped cluster.
Sourcepub fn get_offset_for_x(&self, x: f32) -> usize
pub fn get_offset_for_x(&self, x: f32) -> usize
Returns byte offset for X position. Uses binary search for monotonic positions and nearest-edge lookup for bidirectional text.
Sourcepub fn is_valid_for(&self, text: &str) -> bool
pub fn is_valid_for(&self, text: &str) -> bool
Checks if this layout result is valid for the given text.
Sourcepub fn glyph_layouts(&self) -> &[GlyphLayout]
pub fn glyph_layouts(&self) -> &[GlyphLayout]
Returns visual glyph boxes emitted by shaping/layout.
Sourcepub fn monospaced(text: &str, char_width: f32, line_height: f32) -> Self
pub fn monospaced(text: &str, char_width: f32, line_height: f32) -> Self
Creates a simple layout for monospaced text (for fallback).