pub struct BasicTextFieldDecorationScope { /* private fields */ }Expand description
Scope passed to a basic text field decoration box.
The decoration may place arbitrary composables around the editable content,
but must call inner_text_field exactly once.
Implementations
Sourceimpl BasicTextFieldDecorationScope
impl BasicTextFieldDecorationScope
pub fn inner_text_field(&self) -> NodeId