Module clickable_text

Module clickable_text 

ClickableText widget for handling clicks on annotated text.

Mirrors Jetpack Compose’s ClickableText from: compose/foundation/foundation/src/commonMain/kotlin/androidx/compose/foundation/text/ClickableText.kt

Functions

ClickableText
Displays an AnnotatedString and calls on_click with the byte offset of the character under the pointer at the time of the click.