pub fn BitmapRegionPainter(
bitmap: ImageBitmap,
source: Rect,
sampling: ImageSampling,
) -> PainterExpand description
Creates a painter that draws one region from a bitmap atlas.
pub fn BitmapRegionPainter(
bitmap: ImageBitmap,
source: Rect,
sampling: ImageSampling,
) -> PainterCreates a painter that draws one region from a bitmap atlas.