LinearArrangement

Enum LinearArrangement 

pub enum LinearArrangement {
    Start,
    End,
    Center,
    SpaceBetween,
    SpaceAround,
    SpaceEvenly,
    SpacedBy(f32),
}
Arrangement strategy matching Jetpack Compose’s linear arrangements.

Variants



Start

Place children consecutively starting from the leading edge.



End

Place children so the last child touches the trailing edge.



Center

Place children so they are centered as a block.



SpaceBetween

Distribute the remaining space evenly between children.



SpaceAround

Distribute the remaining space before, after, and between children.



SpaceEvenly

Distribute the remaining space before the first child, between children, and after the last child.



SpacedBy(f32)

Insert a fixed amount of space between children.

Implementations

Source

impl LinearArrangement

pub fn spaced_by(spacing: f32) -> LinearArrangement

Creates an arrangement that inserts a fixed spacing between children.