pub fn ProvideLanguagePreferences(
application: Localization,
system: &[Locale],
content: impl FnOnce(),
)Expand description
Provides automatic language selection and stored overrides to a UI subtree.
Native applications normally use cranpose::ProvideApplicationLocalization,
which supplies and refreshes the host language list automatically.