pub struct TextFieldValue {
pub text: String,
pub selection: TextRange,
pub composition: Option<TextRange>,
}Expand description
Immutable snapshot of text field content.
This represents the text, selection, and composition state at a point in time.
Fields
text: StringThe text content
selection: TextRangeCurrent selection or cursor position
composition: Option<TextRange>IME composition range, if any
Implementations
Sourceimpl TextFieldValue
impl TextFieldValue
Sourcepub fn new(text: impl Into<String>) -> TextFieldValue
pub fn new(text: impl Into<String>) -> TextFieldValue
Creates a new value with the given text and cursor at end.
Sourcepub fn with_selection(
text: impl Into<String>,
selection: TextRange,
) -> TextFieldValue
pub fn with_selection( text: impl Into<String>, selection: TextRange, ) -> TextFieldValue
Creates a value with specified text and selection.