pub struct WindowRootRegistry { /* private fields */ }Expand description
The window roots attached in an app context, in attach order, with a revision that changes whenever the set changes.
Implementations