Module annotated_string

Module annotated_string 

Structs

AnnotatedString
The basic data structure of text with multiple styles.
Builder
A builder to construct AnnotatedString.
RangeStyle
A style applied to a range of an AnnotatedString.