pub struct AnnotatedString {
pub text: String,
pub span_styles: Vec<RangeStyle<SpanStyle>>,
pub paragraph_styles: Vec<RangeStyle<ParagraphStyle>>,
}Expand description
The basic data structure of text with multiple styles.
To construct an AnnotatedString you can use AnnotatedString::builder().
Fields
text: Stringspan_styles: Vec<RangeStyle<SpanStyle>>paragraph_styles: Vec<RangeStyle<ParagraphStyle>>Implementations
Sourceimpl AnnotatedString
impl AnnotatedString
pub fn new(text: String) -> Self
pub fn builder() -> Builder
pub fn len(&self) -> usize
pub fn is_empty(&self) -> bool
Sourcepub fn span_boundaries(&self) -> Vec<usize>
pub fn span_boundaries(&self) -> Vec<usize>
Returns a sorted list of unique byte indices where styles change.
Sourcepub fn span_styles_hash(&self) -> u64
pub fn span_styles_hash(&self) -> u64
Computes a hash representing the contents of the span styles, suitable for cache invalidation.
Sourcepub fn subsequence(&self, range: Range<usize>) -> Self
pub fn subsequence(&self, range: Range<usize>) -> Self
Returns a new AnnotatedString containing a substring of the original text
and any styles that overlap with the new range, with indices adjusted.