pub fn Text<S>(value: S, modifier: Modifier, style: TextStyle) -> NodeIdExpand description
Displays plain or annotated text with the supplied style. The modifier controls layout, appearance and input around the text.
Example
use cranpose_ui::*;
#[composable]
fn Greeting() {
Text(
"Hello",
Modifier::empty().padding(16.0),
TextStyle::default(),
);
}